/*
  ******************************************************************************
  * @file    apt32f172_spi.c
  * @author  APT AE Team
  * @version V1.12
  * @date    2019/03/08
  ******************************************************************************
  *THIS SOFTWARE WHICH IS FOR ILLUSTRATIVE PURPOSES ONLY WHICH PROVIDES 
  *CUSTOMER WITH CODING INFORMATION REGARDING THEIR PRODUCTS.
  *APT CHIP SHALL NOT BE HELD RESPONSIBILITY ADN LIABILITY FOR ANY DIRECT, 
  *INDIRECT DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF 
  *SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION 
  *CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.AND APT CHIP RESERVES 
  *THE RIGHT TO MAKE CHANGES IN THE SOFTWARE WITHOUT NOTIFICATION
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/ 
#include "apt32f172_spi.h"
/* defines -------------------------------------------------------------------*/

/* -------- variables ---------------------------------------------------------*/

/* externs--------------------------------------------------------------------*/

/*************************************************************/
//SPI RESET,CLEAR ALL REGISTER
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI_DeInit(void)
{
    SPI0->CR0   	= SPI_CR0_RST;
    SPI0->CR1   	= SPI_CR1_RST;
    SPI0->DR   	 	= SPI_DR_RST;
    SPI0->SR   	 	= SPI_SR_RST;
    SPI0->CPSR   	= SPI_CPSR_RST;
    SPI0->IMSCR   	= SPI_IMSCR_RST;
    SPI0->RISR   	= SPI_RISR_RST;
    SPI0->MISR   	= SPI_MISR_RST;
    SPI0->ICR	 	= SPI_ICR_RST;
}
/*************************************************************/
//SPI NSS IO Initial
//EntryParameter:SPI_NSS_IO_GROUP
//SPI_NSS_IO_GROUP:0~2
//ReturnValue:NONE
/*************************************************************/
void SPI_NSS_IO_Init(U8_T SPI_NSS_IO_GROUP)
{
	if(SPI_NSS_IO_GROUP==0)
	{
		GPIOC0->CONLR = (GPIOC0->CONLR&0XFFFFFFF0)  | 0x00000004;				//PC0.0
	}
	else if(SPI_NSS_IO_GROUP==1)
	{
		GPIOA0->CONLR = (GPIOA0->CONLR&0X0FFFFFFF)  | 0x60000000;				//PA0.7
	}
	else if(SPI_NSS_IO_GROUP==2)
	{
		GPIOB0->CONLR = (GPIOB0->CONLR&0XFFFFFFF0)  | 0x00000005;				//PB0.0
	}
}
/*************************************************************/
//SPI Master Init 	
//EntryParameter:SPI_IO,SPI_DATA_SIZE_x,SPI_SPO_X,SPI_SPH_X,SPI_LBM_X,SPI_SCR,SPI_CPSDVSR
//SPI_IO:SPI_G0,SPI_G1
//SPI_DATA_SIZE_x:SPI_DATA_SIZE_4BIT~SPI_DATA_SIZE_16BIT
//SPI_SPO_X:SPI_SPO_0,SPI_SPO_1
//SPI_SPH_X:SPI_SPH_0,SPI_SPH_1
//SPI_LBM_X:SPI_LBM_0,SPI_LBM_1
//SPI_RXIFLSEL_X:SPI_RXIFLSEL_1_8,SPI_RXIFLSEL_1_4,SPI_RXIFLSEL_1_2
//SPI_SCR:0~255
//SPI_CPSDVSR:2~254,必须是2到254之间的偶数
//ReturnValue:NONE
/*************************************************************/
//SPI波特率:FSSPCLK = FPCLK / (CPSDVR × (1 + SCR))
//FPCLK (max) → 2 × FSSPCLKOUT (max)主机	最快波特率
void SPI_Master_Init(SPI_IO_TypeDef SPI_IO , SPI_DATA_SIZE_TypeDef SPI_DATA_SIZE_x , SPI_SPO_TypeDef SPI_SPO_X , SPI_SPH_TypeDef SPI_SPH_X , SPI_LBM_TypeDef SPI_LBM_X , SPI_RXIFLSEL_TypeDef SPI_RXIFLSEL_X , U8_T SPI_SCR , U8_T SPI_CPSDVSR )
{
	//U16_T rdata=0;
	if (SPI_IO==SPI_G0)
    {
		GPIOA1->CONLR = (GPIOA1->CONLR&0XFF000FFF)  | 0x00444000;            //PA1.3->SPI_SCK,PA1.4->SPI_MISO,PA1.5->SPI_MOSI
    }
    else if(SPI_IO==SPI_G1)
    {
		GPIOA0->CONHR = (GPIOA0->CONHR&0XFFFFF000)  | 0x00000666;            //PA0.8->SPI_SCK,PA0.9->SPI_MISO,PA0.10->SPI_MOSI
    }
	SPI0->CR0|=SPI_DATA_SIZE_x|(SPI_SPO_X<<6)|(SPI_SPH_X<<7)|(SPI_SCR<<8);
	SPI0->CPSR=SPI_CPSDVSR;
	SPI0->CR1|=0X02|SPI_LBM_X|(SPI_RXIFLSEL_X<<4);
	//rdata=SPI0->DR;
}
/*************************************************************/
//SPI Slave Init 	
//EntryParameter:SPI_IO,SPI_DATA_SIZE_x,SPI_RXIFLSEL_X,SPI_SCR,SPI_CPSDVSR
//SPI_DATA_SIZE_x:SPI_DATA_SIZE_4BIT~SPI_DATA_SIZE_16BIT
//SPI_RXIFLSEL_X:SPI_RXIFLSEL_1_8,SPI_RXIFLSEL_1_4,SPI_RXIFLSEL_1_2
//SPI_SCR:0~255
//SPI_CPSDVSR:2~254,必须是2到254之间的偶数
//ReturnValue:NONE
/*************************************************************/
//SPI波特率:FSSPCLK = FPCLK / (CPSDVR × (1 + SCR))
//FPCLK (max) → 12 × FSSPCLKIN (max)从机	最快波特率
void SPI_Slave_Init(SPI_IO_TypeDef SPI_IO , SPI_DATA_SIZE_TypeDef SPI_DATA_SIZE_x , SPI_RXIFLSEL_TypeDef SPI_RXIFLSEL_X , U8_T SPI_SCR , U8_T SPI_CPSDVSR)
{
	//U16_T rdata=0;
	if (SPI_IO==SPI_G0)
    {
		GPIOA1->CONLR = (GPIOA1->CONLR&0XFF000FFF)  | 0x00444000;            //PA1.3->SPI_SCK,PA1.4->SPI_MISO,PA1.5->SPI_MOSI
    }
    else if(SPI_IO==SPI_G1)
    {
		GPIOA0->CONHR = (GPIOA0->CONHR&0XFFFFF000)  | 0x00000666;            //PA0.8->SPI_SCK,PA0.9->SPI_MISO,PA0.9->SPI_MOSI
    }
	SPI0->CR0|=SPI_DATA_SIZE_x|(SPI_SCR<<8);
	SPI0->CPSR=SPI_CPSDVSR;
	SPI0->CR1|=0X06|(SPI_RXIFLSEL_X<<4);
	//rdata=SPI0->DR;
}
/*************************************************************/
//SPI Interrupt enable
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI_WRITE_BYTE(U16_T wdata)
{
	while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	
	SPI0->DR = wdata;
	while(((SPI0->SR) & SSP_BSY) == SSP_BSY);		//wait for transmition finish
}

U16_T SPI_READ_BYTE(U16_T wdata)
{
	U16_T rdata=0;
	while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	
	SPI0->DR = wdata;
	while(((SPI0->SR) & SSP_RNE) != SSP_RNE);	
	rdata = SPI0->DR;  	//get data from FIFO
	while(((SPI0->SR) & SSP_BSY) == SSP_BSY);		//wait for transmition finish
	return rdata;
}
/*************************************************************/
//SPI inturrpt Configure
//EntryParameter:SPI_IMSCR_X,NewState
//SPI_IMSCR_X:SPI_PORIM,SPI_RTIM,SPI_RXIM,SPI_TXIM
//NewState:ENABLE,DISABLE
//ReturnValue:NONE
/*************************************************************/ 
void SPI_ConfigInterrupt_CMD(SPI_IMSCR_TypeDef SPI_IMSCR_X , FunctionalStatus NewState)
{
	if (NewState != DISABLE)
	{
		SPI0->IMSCR  |= SPI_IMSCR_X;						//SET
	}
	else
	{
		SPI0->IMSCR  &= ~SPI_IMSCR_X;					//CLR
	}
}   
/*************************************************************/
//SPI Interrupt enable
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI_Int_Enable(void)
{
    INTC_ISER_WRITE(SPI_INT);    
}
/*************************************************************/
//SPI Interrupt disalbe
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI_Int_Disable(void)
{
    INTC_ICER_WRITE(SPI_INT);    
}
/*************************************************************/
//SPI Interrupt wake up enable
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI_Wakeup_Enable(void)
{
    INTC_IWER_WRITE(SPI_INT);    
}

/*************************************************************/
//SPI Interrupt wake up disalbe
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI_Wakeup_Disable(void)
{
    INTC_IWDR_WRITE(SPI_INT);    
}


/******************* (C) COPYRIGHT 2018 APT Chip *****END OF FILE****/